#!/bin/bash
set -euo pipefail

# shellcheck disable=SC1091
source "${AGENT_PATH}/common.sh"
_check_required_env_vars "SERVER" "SERVICE" "TEMP_DIR" "GITEA_RUNNER_DIRECTORY" "ACT_RUNNER_VERSION"

echo "Downloading act_runner ${ACT_RUNNER_VERSION}..."
wget https://gitea.com/gitea/act_runner/releases/download/v${ACT_RUNNER_VERSION}/act_runner-${ACT_RUNNER_VERSION}-linux-amd64 -O "${TEMP_DIR}/act_runner"

chmod +x "${TEMP_DIR}/act_runner" || _die "Failed to download ${TEMP_DIR}/act_runner"

ACT_RUNNER="${GITEA_RUNNER_DIRECTORY}/act_runner"

mkdir -p "${GITEA_RUNNER_DIRECTORY}" || _die "Failed to create ${GITEA_RUNNER_DIRECTORY}"
cp "${TEMP_DIR}/act_runner" "$ACT_RUNNER" || _die "Failed to copy ${TEMP_DIR}/act_runner to ${GITEA_RUNNER_DIRECTORY}/act_runner"

${ACT_RUNNER} --version || _die "Failed to run ${ACT_RUNNER}"
${ACT_RUNNER} generate-config > "${GITEA_RUNNER_DIRECTORY}/config.yaml" || _die "Failed to generate config.yaml"

${ACT_RUNNER} --config "${GITEA_RUNNER_DIRECTORY}/config.yaml" \
    register --no-interactive \
    --instance GITEA_URL \
    --token "${GITEA_TOKEN}" \
    --name "${GITEA_RUNNER_NAME}" \
    --labels "${GITEA_RUNNER_LABELS}"


./start.sh || _die "Failed to start"

echo "Installation complete for service ${SERVICE}."
